function model = gpDynamicsSetLatentValues(model, X)

% GPDYNAMICSSETLATENTVALUES Set the latent values inside the model.
%
%	Description:
%
%	MODEL = GPDYNAMICSSETLATENTVALUES(MODEL, X) Distributes GP-LVM
%	latent positions throughout the GP dynamics model.
%	 Returns:
%	  MODEL - the updated model with the relevant latent positions in
%	   place.
%	 Arguments:
%	  MODEL - the model in which the latent positions are to be placed.
%	  X - the latent positions to be placed in the model.
%	
%
%	See also
%	GPDYNAMICSCREATE, GPDYNAMICSLOGLIKELIHOOD


%	Copyright (c) 2006 Neil D. Lawrence and Cark Henrik Ek
% 	gpDynamicsSetLatentValues.m version 1.5


ind_in = [];
ind_out = []; 
startVal=1;
for i = 1:length(model.seq)
  endVal = model.seq(i);
  ind_in = [ind_in startVal:endVal-1];
  ind_out = [ind_out startVal+1:endVal];
  startVal = endVal + 1;
end

model.X = X(ind_in, :);

if model.diff
  model.y = X(ind_out, :) - X(ind_in, :);
else
  model.y = X(ind_out, :);
end
model.m = gpComputeM(model);


